@@ -1,7 +1,7 @@
 package Crypt::Password::Util;
 
 our $DATE = '2015-01-31'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -127,7 +127,7 @@ Crypt::Password::Util - Crypt password utilities
 
 =head1 VERSION
 
-This document describes version 0.11 of Crypt::Password::Util (from Perl distribution Crypt-Password-Util), released on 2015-01-31.
+This document describes version 0.12 of Crypt::Password::Util (from Perl distribution Crypt-Password-Util), released on 2015-01-31.
 
 =head1 SYNOPSIS
 
@@ -143,8 +143,8 @@ This document describes version 0.11 of Crypt::Password::Util (from Perl distrib
  say crypt_type('foo');                              # undef
 
  # return detailed information
- say crypt_type('$1$$oXYGukVGYa16SN.Pw5vNt/', 1);
- # => {}
+ my $res = crypt_type('$1$$oXYGukVGYa16SN.Pw5vNt/', 1);
+ # => {type=>'MD5-CRYPT', header=>'$1$', salt=>'', hash=>'oXYGukVGYa16SN.Pw5vNt/'}
 
  say looks_like_crypt('62F4a6/89.12z');   # 1
  say looks_like_crypt('foo');             # 0
